@@ -14,11 +14,11 @@ using namespace Rcpp;
 //' @return Vector with the energy cost of locomotion (EnergyScape)
 // [[Rcpp::export]]
 NumericVector energy (
-    NumericVector slope ,
-    NumericVector distance ,
-    double mass ,
-    double res ,
-    bool kcal = true
+    double mass,
+    NumericVector slope,
+    NumericVector distance,
+    double res,
+    bool kcal
 ) {
   const double PI =  3.1415926535;
   const double KCAL = 4184.0;
@@ -48,10 +48,10 @@ NumericVector energy (
 // [[Rcpp::export]]
 NumericMatrix energyscape (
     NumericMatrix x,
-    int n = 4,
-    double mass = 0,
-    double res = 0,
-    bool kcal = true
+    double mass,
+    int n,
+    double res,
+    bool kcal
 ) {
   if (mass == 0 || res == 0) {
     return 0;
@@ -71,7 +71,7 @@ NumericMatrix energyscape (
       }
       sl = slope(neigh, x(i, j), res);
       dist = distances(neigh, x(i, j), res);
-      en = energy(sl, dist, mass, res, kcal);
+      en = energy(mass, sl, dist, res, kcal);
       ans(i, j) = mean(en);
     }
   }
