@@ -44,7 +44,7 @@ test_that("Energy works", {
   sl <- slope(n, m[2, 2], 1)
   dist <- distances(n, 1, 10)
   mass <- 1000
-  en <- energy(sl, dist, mass, 1, FALSE)
+  en <- energy(mass, sl, dist, 1, FALSE)
   ar <- 8.0 * mass ^ -0.34
   mec <- 50.0 * (1.0 + sin((2.0 * sl - 74.0) / 180.0 * pi)) * mass ^ -0.12
   work <- (ar + mec) * mass * dist;
